@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-static
 version: 1.5.0.3
-id: yesod-static-1.5.0.3-ccd899f592271273f0a2a6db58b65870
-key: yesod_9P9IsCWxXvI7sY5aUIdZ1K
+id: yesod-static-1.5.0.3-2bc87d4464cddb59d7480c11330f08e3
+key: yesod_4p8OpkhYgOt35CBQ0NXbge
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -23,7 +23,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
-hs-libraries: HSyesod-static-1.5.0.3-9P9IsCWxXvI7sY5aUIdZ1K
+hs-libraries: HSyesod-static-1.5.0.3-4p8OpkhYgOt35CBQ0NXbge
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -35,15 +35,15 @@ depends:
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
-    cryptohash-conduit-0.1.1-5005219a38662db9db612b5cadde2085
+    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
+    cryptohash-conduit-0.1.1-9cd42855330eec21f69d5ac4f36d7158
     css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    hjsmin-0.2.0.1-46670f54640c2d75932d2d7d196eac09
+    hjsmin-0.2.0.1-9b584074a533f56bfeee2bd0e05cbecb
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
@@ -55,8 +55,8 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-app-static-3.1.4.1-115f9b28497996c14844e54c77ac724e
-    yesod-core-1.4.19-af1bfc6a6dd9bd0b41ee49e8528d9426
+    wai-app-static-3.1.4.1-2771ede2f82f698f69c7f5569f69b185
+    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
 haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
 haddock-html: /usr/share/doc/haskell-yesod-static/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
